@@ -19,7 +19,10 @@ class GlueCredentials(Credentials):
     security_configuration: Optional[str] = None
     connections: Optional[str] = None
     conf: Optional[str] = None
-    
+    extra_py_files: Optional[str] = None
+    delta_athena_prefix: Optional[str] = None
+    tags: Optional[str] = None
+
     @property
     def type(self):
         return "glue"
@@ -46,5 +49,8 @@ class GlueCredentials(Credentials):
             'glue_version',
             'security_configuration',
             'connections',
-            'conf'
+            'conf',
+            'extra_py_files',
+            'delta_athena_prefix',
+            'tags'
         ]
